import { Controller, Get, Query } from '@nestjs/common';
import { ApiOperation, ApiQuery, ApiTags } from '@nestjs/swagger';
import { Serealize } from '../interceptors/serialize.interceptor';
import { MultaService } from './multa.service';
import { IdEquipoPaginaDto } from '../dto/id-equipo-pagina.dto';
import { MultasDto } from './dto/input/multas.dto';
import { MultaUsuarioDto } from './dto/input/usuario.dto';

@Controller('multa')
@ApiTags('multa')
export class MultaController {
  constructor(private multaService: MultaService) {}

  @Get()
  @ApiOperation({
    description: 'Endpoint que retorna todas las multas de una institución.',
  })
  @ApiQuery({
    description: 'Id de la institución.',
    name: 'id_institucion',
    type: 'string',
  })
  @ApiQuery({
    description: 'Página en la que se encuentra el usuario.',
    name: 'pagina',
    type: 'string',
  })
  multas(@Query() query: MultasDto) {
    return this.multaService.findAll(query);
  }

  @Get('multas-equipo')
  @ApiOperation({
    description: 'Endpoint que retorna todas las multas de un equipo.',
  })
  @ApiQuery({
    description: 'Id del equipo.',
    name: 'id_equipo',
    type: 'string',
  })
  @ApiQuery({
    description: 'Página en la que se encuentra el usuario',
    name: 'pagina',
    type: 'string',
  })
  multasEquipo(@Query() query: IdEquipoPaginaDto) {
    return this.multaService.findAllByIdEquipo(
      parseInt(query.id_equipo),
      parseInt(query.pagina),
    );
  }

  @Get('multas-usuario')
  @ApiOperation({
    description: 'Endpoint que retorna todas las multas de un usuario .',
  })
  @ApiQuery({
    description: 'Id del usuario.',
    name: 'id_usuario',
    type: 'string',
  })
  @ApiQuery({
    description: 'Página en la que se encuentra el usuario',
    name: 'pagina',
    type: 'string',
  })
  multasUsuario(@Query() query: MultaUsuarioDto) {}

  // @Get('reporte')
  // reporte() {}
}
